lkml.org 
[lkml]   [2003]   [Sep]   [11]   [last100]   RSS Feed
Views: [wrap][no wrap]   [headers]  [forward] 
 
Messages in this thread
Patch in this message
/
From
Subject[PATCH-2.6.0-test5-mm1] conversion of schedule_task to schedule_work
Date
Hi,

The following patch converts one 'schedule_task'
in the code, and one 'schedule_task' in a comment
to 'schedule_work'. The file changed is drivers/char/istallion.c
The patch applies against 2.6.0-test5-mm1.

Regards
KK

============================
Compilation Warning removed:
drivers/char/istallion.c:2947: warning: implicit declaration of function `schedule_task'
drivers/char/istallion.c: In function `stli_startbrd':

Linking warning removed:
drivers/built-in.o(.text+0x25e73): In function `stli_poll':
: undefined reference to `schedule_task'

=============================
diffstat output:

istallion.c | 4 ++--
1 files changed, 2 insertions(+), 2 deletions(-)

=============================
The following is the patch:

--- linux-2.6.0-test5-mm1/drivers/char/istallion.orig.c 2003-09-11 14:51:35.000000000 +0530
+++ linux-2.6.0-test5-mm1/drivers/char/istallion.c 2003-09-11 14:52:06.000000000 +0530
@@ -2303,7 +2303,7 @@

/*
* FIXME: There's a module removal race here: tty_hangup
* calls schedule_task which will call into this
* driver later.
*/
portp = (stliport_t *) arg;
@@ -2944,7 +2944,7 @@
((portp->sigs & TIOCM_CD) == 0)) {
if (portp->flags & ASYNC_CHECK_CD) {
if (tty)
- schedule_task(&portp->tqhangup);
+ schedule_work(&portp->tqhangup);
}
}
}



-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@vger.kernel.org
More majordomo info at http://vger.kernel.org/majordomo-info.html
@@ -2303,7 +2303,7 @@
/*
* FIXME: There's a module removal race here: tty_hangup
- * calls schedule_task which will call into this
+ * calls schedule_work which will call into this
* driver later.
*/
Please read the FAQ at http://www.tux.org/lkml/

\
 
 \ /
  Last update: 2005-03-22 13:48    [W:0.138 / U:0.964 seconds]
©2003-2020 Jasper Spaans|hosted at Digital Ocean and TransIP|Read the blog|Advertise on this site